/* GTK NAMED COLORS ---------------- use responsibly! */
@define-color destructive_bg_color @red_3;
@define-color destructive_fg_color white;
@define-color success_bg_color @green_4;
@define-color success_fg_color white;
@define-color warning_bg_color @yellow_5;
@define-color warning_fg_color RGB(0 0 0 / 80%);
@define-color error_bg_color @red_3;
@define-color error_fg_color white;
@define-color accent_color oklab(from @accent_bg_color min(l, 0.5) a b);
@define-color destructive_color oklab(from @destructive_bg_color min(l, 0.5) a b);
@define-color success_color oklab(from @success_bg_color min(l, 0.5) a b);
@define-color warning_color oklab(from @warning_bg_color min(l, 0.5) a b);
@define-color error_color oklab(from @error_bg_color min(l, 0.5) a b);
@define-color window_bg_color #fafafb;
@define-color window_fg_color RGB(0 0 6/80%);
@define-color view_bg_color #ffffff;
@define-color view_fg_color RGB(0 0 6/80%);
@define-color headerbar_bg_color #ffffff;
@define-color headerbar_fg_color RGB(0 0 6/80%);
@define-color headerbar_border_color RGB(0 0 6/80%);
@define-color headerbar_backdrop_color @window_bg_color;
@define-color headerbar_shade_color RGB(0 0 6/12%);
@define-color headerbar_darker_shade_color RGB(0 0 6/12%);
@define-color sidebar_bg_color #ebebed;
@define-color sidebar_fg_color RGB(0 0 6/80%);
@define-color sidebar_backdrop_color #f2f2f4;
@define-color sidebar_shade_color RGB(0 0 6/7%);
@define-color sidebar_border_color RGB(0 0 6/7%);
@define-color secondary_sidebar_bg_color #f3f3f5;
@define-color secondary_sidebar_fg_color RGB(0 0 6/80%);
@define-color secondary_sidebar_backdrop_color #f6f6fa;
@define-color secondary_sidebar_shade_color RGB(0 0 6/7%);
@define-color secondary_sidebar_border_color RGB(0 0 6/7%);
@define-color card_bg_color #ffffff;
@define-color card_fg_color RGB(0 0 6/80%);
@define-color card_shade_color RGB(0 0 6/7%);
@define-color dialog_bg_color #fafafb;
@define-color dialog_fg_color RGB(0 0 6/80%);
@define-color popover_bg_color #ffffff;
@define-color popover_fg_color RGB(0 0 6/80%);
@define-color popover_shade_color RGB(0 0 6/7%);
@define-color thumbnail_bg_color #ffffff;
@define-color thumbnail_fg_color RGB(0 0 6/80%);
@define-color shade_color RGB(0 0 6/7%);
@define-color scrollbar_outline_color white;
:root { --standalone-color-oklab: min(l, 0.5) a b; --accent-color: oklab(
    from var(--accent-bg-color) var(--standalone-color-oklab)
  ); --destructive-color: oklab(
    from var(--destructive-bg-color) var(--standalone-color-oklab)
  ); --success-color: oklab(
    from var(--success-bg-color) var(--standalone-color-oklab)
  ); --warning-color: oklab(
    from var(--warning-bg-color) var(--standalone-color-oklab)
  ); --error-color: oklab(
    from var(--error-bg-color) var(--standalone-color-oklab)
  ); --active-toggle-bg-color: #ffffff; --active-toggle-fg-color: rgb(0 0 6 / 80%); --overview-bg-color: #f3f3f5; --overview-fg-color: rgb(0 0 6 / 80%); }
@import '../gtk-3.0/libadwaita.css';
@import '../gtk-3.0/libadwaita-tweaks.css';
